==> istio-model-v1alpha3-6.6.0-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ValueNumberValueFluentImpl.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.lang.Double;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ValueNumberValueFluentImpl<A extends ValueNumberValueFluent<A>> extends BaseFluent<A> implements ValueNumberValueFluent<A>{
  public ValueNumberValueFluentImpl() {
  }
  public ValueNumberValueFluentImpl(ValueNumberValue instance) {
    this.withNumberValue(instance.getNumberValue()); 
  }
  private Double numberValue;
  public Double getNumberValue() {
    return this.numberValue;
  }
  public A withNumberValue(Double numberValue) {
    this.numberValue=numberValue; return (A) this;
  }
  public Boolean hasNumberValue() {
    return this.numberValue != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ValueNumberValueFluentImpl that = (ValueNumberValueFluentImpl) o;
    if (numberValue != null ? !numberValue.equals(that.numberValue) :that.numberValue != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(numberValue,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (numberValue != null) { sb.append("numberValue:"); sb.append(numberValue); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.7.1-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ValueNumberValueFluentImpl.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.lang.Double;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ValueNumberValueFluentImpl<A extends ValueNumberValueFluent<A>> extends BaseFluent<A> implements ValueNumberValueFluent<A>{
  public ValueNumberValueFluentImpl() {
  }
  public ValueNumberValueFluentImpl(ValueNumberValue instance) {
    if (instance != null) {
      this.withNumberValue(instance.getNumberValue());
    }
  }
  private Double numberValue;
  public Double getNumberValue() {
    return this.numberValue;
  }
  public A withNumberValue(Double numberValue) {
    this.numberValue=numberValue; return (A) this;
  }
  public Boolean hasNumberValue() {
    return this.numberValue != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValueNumberValueFluentImpl that = (ValueNumberValueFluentImpl) o;
    if (!java.util.Objects.equals(numberValue, that.numberValue)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(numberValue,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (numberValue != null) { sb.append("numberValue:"); sb.append(numberValue); }
    sb.append("}");
    return sb.toString();
  }
  
}
